function [X,codigo]=transmite(simbolo,Nt,L,M,h,flag,hiper)

    %Nt: nro. de supersimbolos que transmitimos
    %L: longitud de CP o ZP
    %M: nro. de portadoras a utilizar (nro. de puntos de la fft)----->M=64;
    %Flag: bandera binaria para indicar la eleccion de ZP o CP. 
    %si Flag=0 entonces utilizaremos las matrices de CP en otro caso seran las de ZP.
    %datos:nro. de portadoras que se utilizan para datos
    F=matrizifft(L,M);
    B=1;            %       B= nro de simbolos que transmitiremos a la vez
    [So,codigo]=generaSo(M,B,simbolo);
    if flag==0
        T=matrizTcp(L,M);
        H=matrizcanalcp(h,L,M);    %la h es la salida de la funcion channelHL2
    else
        T=matrizTzp(L,M);
        H=matrizcanalzp(h,L,M);    %la h es la salida de la funcion channelHL2
    end
    
    Fo=F*So;
    A=T*Fo;
    X=H*A;
   

        